]> sigrok.org Git - pulseview.git/blobdiff - main.cpp
Indented if statements in CMakeLists.txt
[pulseview.git] / main.cpp
index 3d6b86e3651b3004c95d87c8d7d0c77c41024613..41f85897893069165afc325d5db4d65a414ab36e 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -1,5 +1,5 @@
 /*
* This file is part of the sigrok project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>
  *
@@ -26,7 +26,7 @@ extern "C" {
 
 #include <QtGui/QApplication>
 #include <QDebug>
-#include "mainwindow.h"
+#include "pv/mainwindow.h"
 
 int main(int argc, char *argv[])
 {
@@ -34,7 +34,7 @@ int main(int argc, char *argv[])
 
        /* Set some application metadata. */
        QApplication::setApplicationVersion(APP_VERSION);
-       QApplication::setApplicationName("sigrok-qt");
+       QApplication::setApplicationName("PulseView");
        QApplication::setOrganizationDomain("http://www.sigrok.org");
 
        /* Initialise libsigrok */
@@ -63,7 +63,7 @@ int main(int argc, char *argv[])
        }
 
        /* Initialise the main window */
-       MainWindow w;
+       pv::MainWindow w;
        w.show();
 
        /* Run the application */
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the PulseView project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>